@@ -1,23 +1,25 @@
-/* $Id: command.h,v 1.17 1998/10/26 10:38:44 martin Exp $ */
+/* $Id$ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_COMMAND_H__
 #define __GLIBTOP_COMMAND_H__
@@ -26,7 +28,7 @@
 #include <glibtop/sysdeps.h>
 #include <glibtop/union.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_CMND_QUIT		0
 #define GLIBTOP_CMND_SYSDEPS		1
@@ -87,9 +89,14 @@ struct _glibtop_response
 
 #define glibtop_call(p1, p2, p3, p4)	glibtop_call_r(glibtop_global_server, p1, p2, p3, p4)
 
-extern void *glibtop_call_l __P((glibtop *, unsigned, size_t, const void *, size_t, void *));
-extern void *glibtop_call_s __P((glibtop *, unsigned, size_t, const void *, size_t, void *));
+void *
+glibtop_call_l (glibtop *server, unsigned command, size_t send_size,
+		const void *send_buf, size_t recv_size, void *recv_buf);
 
-__END_DECLS
+void *
+glibtop_call_s (glibtop *server, unsigned command, size_t send_size,
+		const void *send_buf, size_t recv_size, void *recv_buf);
+
+END_LIBGTOP_DECLS
 
 #endif
