@@ -1,4 +1,4 @@
-/* $Id: loadavg.c,v 1.6 1999/02/23 11:44:00 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -28,7 +28,7 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_loadavg =
-(1 << GLIBTOP_LOADAVG_LOADAVG);
+(1L << GLIBTOP_LOADAVG_LOADAVG);
 
 /* Init function. */
 
@@ -46,7 +46,7 @@ glibtop_get_loadavg_p (glibtop *server, glibtop_loadavg *buf)
 	double ldavg[3]; 
 	int i;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_LOADAVG), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_LOADAVG), 0);
 	
 	memset (buf, 0, sizeof (glibtop_loadavg));
 
