@@ -1,4 +1,4 @@
-/* $Id: procmem.c,v 1.19 1999/02/24 14:32:00 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -39,19 +39,35 @@
 #include <ufs/ufs/inode.h>
 
 #include <sys/ucred.h>
-#ifndef __OpenBSD__
+#if (!defined __OpenBSD__) && (!defined __bsdi__)
 #include <sys/user.h>
 #endif
 #include <sys/sysctl.h>
 #include <vm/vm.h>
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+/* Fixme ... */
+#undef _KERNEL
+#define _UVM_UVM_AMAP_I_H_ 1
+#define _UVM_UVM_MAP_I_H_ 1
+#include <uvm/uvm.h>
+#endif
+
 static const unsigned long _glibtop_sysdeps_proc_mem =
-(1 << GLIBTOP_PROC_MEM_SIZE) +
-(1 << GLIBTOP_PROC_MEM_VSIZE) +
-(1 << GLIBTOP_PROC_MEM_SHARE) +
-(1 << GLIBTOP_PROC_MEM_RESIDENT) +
-(1 << GLIBTOP_PROC_MEM_RSS) +
-(1 << GLIBTOP_PROC_MEM_RSS_RLIM);
+(1L << GLIBTOP_PROC_MEM_SIZE) +
+(1L << GLIBTOP_PROC_MEM_VSIZE) +
+(1L << GLIBTOP_PROC_MEM_RESIDENT) +
+(1L << GLIBTOP_PROC_MEM_RSS) +
+(1L << GLIBTOP_PROC_MEM_RSS_RLIM);
+
+static const unsigned long _glibtop_sysdeps_proc_mem_share =
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+(1L << GLIBTOP_PROC_MEM_SHARE);
+#elif defined(__FreeBSD__)
+(1L << GLIBTOP_PROC_MEM_SHARE);
+#else
+0;
+#endif
 
 #ifndef LOG1024
 #define LOG1024		10
@@ -82,7 +98,8 @@ glibtop_init_proc_mem_p (glibtop *server)
 	/* we only need the amount of log(2)1024 for our conversion */
 	pageshift -= LOG1024;
 
-	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
+	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem |
+		_glibtop_sysdeps_proc_mem_share;
 }
 
 /* Provides detailed information about a process. */
@@ -94,11 +111,16 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 	struct kinfo_proc *pinfo;
 	struct vm_map_entry entry, *first;
 	struct vmspace *vms, vmspace;
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	struct vnode vnode;
+	struct inode inode;
+#else
 	struct vm_object object;
+#endif
 	struct plimit plimit;
 	int count;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MEM), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MEM), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_mem));
 
@@ -173,11 +195,29 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
  		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
  			continue;
 #endif
+#else
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+ 		if (UVM_ET_ISSUBMAP (&entry))
+			continue;
 #else
 		if (entry.is_a_map || entry.is_sub_map)
 			continue;
 #endif
+#endif
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+		if (!entry.object.uvm_obj)
+			continue;
+
+		/* We're only interested in vnodes */
+
+		if (kvm_read (server->machine.kd,
+			      (unsigned long) entry.object.uvm_obj,
+			      &vnode, sizeof (vnode)) != sizeof (vnode)) {
+			glibtop_warn_io_r (server, "kvm_read (vnode)");
+			return;
+		}
+#else
 		if (!entry.object.vm_object)
 			continue;
 
@@ -189,18 +229,31 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 			glibtop_warn_io_r (server, "kvm_read (object)");
 			return;
 		}
-
+#endif
 		/* If the object is of type vnode, add its size */
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+		if (!vnode.v_uvm.u_flags & UVM_VNODE_VALID)
+			continue;
+
+		if ((vnode.v_type != VREG) || (vnode.v_tag != VT_UFS) ||
+		    !vnode.v_data) continue;
+
+		/* Reference count must be at least two. */
+		if (vnode.v_uvm.u_obj.uo_refs <= 1)
+			continue;
+
+		buf->share += pagetok (vnode.v_uvm.u_obj.uo_npages) << LOG1024;
+#endif
+
 #ifdef __FreeBSD__
 		if (object.type != OBJT_VNODE)
 			continue;
 
 		buf->share += object.un_pager.vnp.vnp_size;
-#else
-		buf->share += object.size;
 #endif
 	}
 
-	buf->flags = _glibtop_sysdeps_proc_mem;
+	buf->flags = _glibtop_sysdeps_proc_mem |
+		_glibtop_sysdeps_proc_mem_share;
 }
